@@ -86,11 +86,13 @@ class ExperimentRepository:
 
     def exportExperiment(self, experiment, root_path):
 
+        experiment.update()
+
         expDir = entityRepository.exportEntity(experiment, root_path)
 
         # export entry
         entryDir = expDir.joinpath('entry')
-        experiment.update().root_experiment.update().export(entryDir)
+        experiment.root_experiment.export(entryDir)
 
         # export protocols
         protocolsDir = expDir.joinpath('protocols')
