@@ -23,7 +23,7 @@ class ExperimentTimer(Entity):
 
         Returns
         -------
-        :class:`~labstep.experiment.ExperimentTimer`
+        :class:`~labstep.entities.experimentTimer.model.ExperimentTimer`
             An object representing the edited Experiment Timer.
 
         Example
