@@ -36,7 +36,7 @@ class ResourceLocation(Entity):
 
         Returns
         -------
-        :class:`~labstep.resourceLocation.ResourceLocation`
+        :class:`~labstep.entities.resourceLocation.model.ResourceLocation`
             An object representing the edited ResourceLocation.
 
         Example
@@ -86,7 +86,7 @@ class ResourceLocation(Entity):
 
         Returns
         -------
-        :class:`~labstep.comment.Comment`
+        :class:`~labstep.entities.comment.model.Comment`
             The comment added.
 
         Example
@@ -115,7 +115,7 @@ class ResourceLocation(Entity):
 
         Returns
         -------
-        :class:`~labstep.resourceLocation.ResourceLocation`
+        :class:`~labstep.entities.resourceLocation.model.ResourceLocation`
             The ResourceLocation that was tagged.
 
         Example
