@@ -70,7 +70,7 @@ class EntityRepository:
         url = url_join(API_ROOT, "/api/generic/",
                        entityClass.__entityName__, "batch")
         response = requestService.post(
-            url, headers=headers, json={"items": items})
+            url, headers=headers, json={"items": items, "group_id": user.activeWorkspace})
         entities = json.loads(response.content)
         return list(map(lambda entity: entityClass(entity, user), entities))
 
